'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var fontSizes = [12, 15, 17, 20, 24, 28, 34, 42, 50, 70];
var fonts = {
  headlineSerif: "GH Guardian Headline, Georgia, serif",
  bodySerif: "GuardianTextEgyptian, Georgia, serif",
  bodySans: "GuardianTextSans, Helvetica Neue, Helvetica, Arial, Lucida Grande, sans-serif"
};
var lineHeights = ["1.15em", "1.35em", "1.45em"];
var fontWeights = [300, 400, 500, 700];
var colors = {
  reds: [],
  oranges: [],
  blues: ["#041f4a", "#052962", "#506991"],
  yellows: ["#ffbb50", "#ffe500"],
  browns: [],
  pinks: [],
  greens: [],
  grays: ["#121212", "#333333", "#767676", "#999999", "#d9d9d9", "#dcdcdc", "#ededed", "#f6f6f6", "#ffffff"]
};
var space = [3, 6, 12, 18, 24, 30, 36, 42, 60, 96];
var size = [24, 36, 42];
var breakpoints = [740, 980, 1140, 1300]; // Diverges from https://system-ui.com
// At these widths, there are tweaks to the
// fluid grid on mobile devices

var tweakpoints = [375, 480, 660];
var transitions = [".2s cubic-bezier(.64, .57, .67, 1.53)", ".45s ease-in-out", ".65s ease-in-out"];

var transitions$1 = {
  "short": transitions[0],
  medium: transitions[1],
  "long": transitions[2]
};

var visuallyHidden = "\n\tposition: absolute;\n\topacity: 0;\n\theight: 0;\n\twidth: 0;\n\ttop: 0;\n\tleft: 0;\n";
var focusHalo = "\n\tbox-shadow: 0 0 0 5px #00B2FF;\n\tz-index: 9;\n";

var mediaQueryMinimums = {
  mobileMedium: tweakpoints[0],
  mobileLandscape: tweakpoints[1],
  phablet: tweakpoints[2],
  tablet: breakpoints[0],
  desktop: breakpoints[1],
  leftCol: breakpoints[2],
  wide: breakpoints[3]
};

var minWidth = function minWidth(value) {
  return "@media (min-width: ".concat(value, "px)");
};

var maxWidth = function maxWidth(value) {
  return "@media (max-width: ".concat(value - 1, "px)");
};

var minWidthMaxWidth = function minWidthMaxWidth(from, until) {
  return "@media (min-width: ".concat("".concat(from, "px"), ") and (max-width: ", "".concat(until - 1, "px"), ")");
};

var mq = function mq(_ref) {
  var from = _ref.from,
      until = _ref.until;

  if (from && until) {
    return minWidthMaxWidth(mediaQueryMinimums[from], mediaQueryMinimums[until]);
  }

  if (from) {
    return minWidth(mediaQueryMinimums[from]);
  }

  return maxWidth(mediaQueryMinimums[until]);
};

var palette = {
  brand: {
    dark: colors.blues[0],
    main: colors.blues[1],
    pastel: colors.blues[2]
  },
  yellow: {
    dark: colors.yellows[0],
    main: colors.yellows[1]
  },
  neutral: {
    7: colors.grays[0],
    20: colors.grays[1],
    46: colors.grays[2],
    60: colors.grays[3],
    85: colors.grays[4],
    86: colors.grays[5],
    93: colors.grays[6],
    97: colors.grays[7],
    100: colors.grays[8]
  }
};

var size$1 = {
  small: size[0],
  medium: size[1],
  large: size[2]
};

var space$1 = {
  half: space[0],
  1: space[1],
  2: space[2],
  3: space[3],
  5: space[5],
  4: space[4],
  7: space[7],
  6: space[6],
  16: space[9],
  10: space[8]
};

var headlineSizes = {
  1: fontSizes[2],
  2: fontSizes[3],
  3: fontSizes[4],
  4: fontSizes[5],
  5: fontSizes[6],
  6: fontSizes[7],
  7: fontSizes[8],
  8: fontSizes[9]
};
var bodySizes = {
  1: fontSizes[1],
  2: fontSizes[2]
};
var textSansSizes = {
  1: fontSizes[0],
  2: fontSizes[1],
  3: fontSizes[2],
  4: fontSizes[3],
  5: fontSizes[4],
  6: fontSizes[5],
  7: fontSizes[6],
  8: fontSizes[7],
  9: fontSizes[8],
  10: fontSizes[9]
};
var fontSizeMapping = {
  headline: headlineSizes,
  body: bodySizes,
  textSans: textSansSizes
};
var fontMapping = {
  headline: fonts.headlineSerif,
  body: fonts.bodySerif,
  textSans: fonts.bodySans
};
var lineHeightMapping = {
  tight: lineHeights[0],
  regular: lineHeights[1],
  loose: lineHeights[2]
};
var fontWeightMapping = {
  headline: {
    light: {
      fontWeight: fontWeights[0],
      hasItalic: true
    },
    medium: {
      fontWeight: fontWeights[2],
      hasItalic: true
    },
    bold: {
      fontWeight: fontWeights[3],
      hasItalic: false
    }
  },
  body: {
    regular: {
      fontWeight: fontWeights[1],
      hasItalic: true
    },
    bold: {
      fontWeight: fontWeights[3],
      hasItalic: true
    }
  },
  textSans: {
    regular: {
      fontWeight: fontWeights[1],
      hasItalic: true
    },
    bold: {
      fontWeight: fontWeights[3],
      hasItalic: false
    }
  }
};

var fs = function fs(_ref) {
  var category = _ref.category,
      level = _ref.level,
      lineHeight = _ref.lineHeight,
      fontWeight = _ref.fontWeight;
  // Gosh there's a lot of flaky logic here! We need to think about
  // what happens if a value is not found. Maybe a big try / catch?
  var fontFamilyValue = fontMapping[category];
  var fontSizeValue = fontSizeMapping[category][level];
  var lineHeightValue = lineHeightMapping[lineHeight];
  var fontWeightValue = fontWeightMapping[category][fontWeight].fontWeight;
  return "\n\tfont-family: ".concat(fontFamilyValue, ";\n\tfont-size: ").concat(fontSizeValue, "px;\n\tline-height: ").concat(lineHeightValue, ";\n\tfont-weight: ").concat(fontWeightValue, ";\n\t");
};

var headline = function headline(_ref2) {
  var level = _ref2.level,
      _ref2$lineHeight = _ref2.lineHeight,
      lineHeight = _ref2$lineHeight === void 0 ? "tight" : _ref2$lineHeight,
      _ref2$fontWeight = _ref2.fontWeight,
      fontWeight = _ref2$fontWeight === void 0 ? "medium" : _ref2$fontWeight;
  return fs({
    category: "headline",
    level: level,
    lineHeight: lineHeight,
    fontWeight: fontWeight
  });
};

var body = function body(_ref3) {
  var level = _ref3.level,
      _ref3$lineHeight = _ref3.lineHeight,
      lineHeight = _ref3$lineHeight === void 0 ? "loose" : _ref3$lineHeight,
      _ref3$fontWeight = _ref3.fontWeight,
      fontWeight = _ref3$fontWeight === void 0 ? "regular" : _ref3$fontWeight;
  return fs({
    category: "body",
    level: level,
    lineHeight: lineHeight,
    fontWeight: fontWeight
  });
};

var textSans = function textSans(_ref4) {
  var level = _ref4.level,
      _ref4$lineHeight = _ref4.lineHeight,
      lineHeight = _ref4$lineHeight === void 0 ? "loose" : _ref4$lineHeight,
      _ref4$fontWeight = _ref4.fontWeight,
      fontWeight = _ref4$fontWeight === void 0 ? "regular" : _ref4$fontWeight;
  return fs({
    category: "textSans",
    level: level,
    lineHeight: lineHeight,
    fontWeight: fontWeight
  });
};

Object.freeze(headlineSizes);
Object.freeze(bodySizes);
Object.freeze(textSansSizes);

exports.body = body;
exports.bodySizes = bodySizes;
exports.focusHalo = focusHalo;
exports.headline = headline;
exports.headlineSizes = headlineSizes;
exports.mq = mq;
exports.palette = palette;
exports.size = size$1;
exports.space = space$1;
exports.textSans = textSans;
exports.textSansSizes = textSansSizes;
exports.transitions = transitions$1;
exports.visuallyHidden = visuallyHidden;
